pub struct FishingHookEntity {
base: EntityBase,
entity_type: EntityTypeRef,
entity_data: SyncMutex<FishingBobberEntityData>,
projectile_base: ProjectileBase,
hook_state: SyncMutex<FishingHookState>,
synchronized_random: SyncMutex<LegacyRandom>,
}Expand description
A fishing hook.
Fields
base: EntityBaseentity_type: EntityTypeRefentity_data: SyncMutex<FishingBobberEntityData>projectile_base: ProjectileBasehook_state: SyncMutex<FishingHookState>synchronized_random: SyncMutex<LegacyRandom>Implementations
Sourceimpl FishingHookEntity
impl FishingHookEntity
Sourcepub fn new(
entity_type: EntityTypeRef,
id: i32,
position: DVec3,
world: Weak<World>,
) -> Self
pub fn new( entity_type: EntityTypeRef, id: i32, position: DVec3, world: Weak<World>, ) -> Self
Creates a fishing hook entity.
We keep both this generic constructor and shoot_from_player in order to ensure future-proofing in terms of a future plugin API.
Sourcepub fn shoot_from_player(
self: &Arc<Self>,
player: &Arc<Player>,
luck: i32,
lure_speed: i32,
)
pub fn shoot_from_player( self: &Arc<Self>, player: &Arc<Player>, luck: i32, lure_speed: i32, )
Mimics Java’s FishingHook(Player, Level, int, int) constructor. (But we don’t need level here)
Sourcepub fn from_saved(entity_type: EntityTypeRef, load: EntityBaseLoad) -> Self
pub fn from_saved(entity_type: EntityTypeRef, load: EntityBaseLoad) -> Self
Creates a fishing hook entity from saved base data.
Sourcepub(crate) fn set_owner(self: &Arc<Self>, owner: &SharedEntity)
pub(crate) fn set_owner(self: &Arc<Self>, owner: &SharedEntity)
Sets the projectile owner and mirrors vanilla’s Player.fishing update.
Sourcefn should_stop_fishing(
&self,
owner: &Player,
mainhand_item: &ItemStack,
offhand_item: &ItemStack,
) -> bool
fn should_stop_fishing( &self, owner: &Player, mainhand_item: &ItemStack, offhand_item: &ItemStack, ) -> bool
Determines if the player should stop fishing and removes the entity if so.
Sourcefn check_collision(&self)
fn check_collision(&self)
Determines if the fishing hook should hit a target or be deflected.
Sourcefn set_hooked_entity(&self, hooked: Option<SharedEntity>)
fn set_hooked_entity(&self, hooked: Option<SharedEntity>)
Stores the currently hooked entity inside entity_data.
Sourcefn catching_fish(&self, pos: BlockPos, state: &mut FishingHookState)
fn catching_fish(&self, pos: BlockPos, state: &mut FishingHookState)
Runs catching fish logic
Sourcefn calculate_open_water(&self, pos: BlockPos) -> bool
fn calculate_open_water(&self, pos: BlockPos) -> bool
Calculates if the area the player is currently fishing in is open water.
Sourcefn get_open_water_type_for_area(
&self,
from: BlockPos,
to: BlockPos,
) -> OpenWaterType
fn get_open_water_type_for_area( &self, from: BlockPos, to: BlockPos, ) -> OpenWaterType
Returns an OpenWaterType for a given area.
Sourcefn get_open_water_type_for_block(&self, pos: BlockPos) -> OpenWaterType
fn get_open_water_type_for_block(&self, pos: BlockPos) -> OpenWaterType
Returns an OpenWaterType for a given block.
Sourcepub fn retrieve(&self, rod: &ItemStack) -> i32
pub fn retrieve(&self, rod: &ItemStack) -> i32
Retrieves the entity caught by this fishing hook and returns the resulting damage value.
Sourcefn pull_entity(&self, entity: &Arc<dyn Entity>)
fn pull_entity(&self, entity: &Arc<dyn Entity>)
Modifies the hooked entities velocity in order to simulate a pulling motion.
Sourcefn clear_owner_info(&self)
fn clear_owner_info(&self)
Clears owner info of this FishingHookEntity
Sourcefn update_owner_info(&self, hook: Option<&Arc<FishingHookEntity>>)
fn update_owner_info(&self, hook: Option<&Arc<FishingHookEntity>>)
Clears owner info if hook is None and stores it, if it is Some
Sourcefn spawn_loot_award_stat(
&self,
items: Vec<ItemStack>,
world: Arc<World>,
owner: Arc<dyn Entity>,
)
fn spawn_loot_award_stat( &self, items: Vec<ItemStack>, world: Arc<World>, owner: Arc<dyn Entity>, )
Loops through a vec of ItemStacks (the fishing loot), spawns them as ItemEntitys in the world and awards the stat FISH_CAUGHT
Sourcefn should_stop(&self) -> bool
fn should_stop(&self) -> bool
Determines if the player should stop fishing.
Sourcefn tick_bobber(
&self,
bobber_state: BobberState,
world: &World,
is_in_water: bool,
pos: BlockPos,
liquid_height: f32,
) -> bool
fn tick_bobber( &self, bobber_state: BobberState, world: &World, is_in_water: bool, pos: BlockPos, liquid_height: f32, ) -> bool
Bobber specific ticking logic. We return a bool here, so we can return early inside tick.
fn tick_life(&self)
fn is_hooked_in(&self) -> bool
fn bobber_state(&self) -> BobberState
fn can_fish(&self, player: &Player) -> bool